@@ -19,7 +19,6 @@
 #include "mmaid.h"
 #include "charlist.h"
 #include "command.h"
-#include "conf.h"
 #include "file.h"
 #include "general.h"
 #include "genre.h"
@@ -30,6 +29,7 @@
 #include "misc/argument.h"
 #include "misc/fileio.h"
 #include "misc/license.h"
+#include "misc/misc_comm.h"
 #include "misc/profile.h"
 
 
@@ -40,19 +40,14 @@ gchar *history_files[10];           /* ja:ファイルの履歴 */
 gchar *open_path = NULL;            /* ja:開くのパス */
 gchar *save_path = NULL;            /* ja:名前を付けて保存のパス */
 gchar *clipboard_id3tag = NULL;     /* ja:クリップボードのタグ */
-gchar *arg_text = NULL;             /* ja:プロセス間通信用変数 */
 gchar *charset_list = NULL;         /* ja:キャラクターセットリスト */
 gchar *genre[256][256];             /* ja:ジャンル */
 gint genres = 0;                    /* ja:ジャンルの数 */
 gint def_gnum = 192;                /* ja:デフォルトのジャンル */
 gint def_width, def_height;         /* ja:デフォルトのウインドウのサイズ */
 gint history = 4;                   /* ja:ファイルの履歴 */
-gint instance = -1;                 /* ja:プロセス間通信用変数 */
-GdkAtom atom_clipboard;             /* ja:クリップボード */
 GdkAtom atom_targets;               /* ja:ターゲット */
 GdkAtom atom_id3tag;                /* ja:ID3タグ */
-GdkAtom atom_melodymaid0;           /* ja:プロセス間通信用アトム */
-GdkAtom atom_melodymaid1;           /* ja:プロセス間通信用アトム */
 GtkWidget *window;                  /* ja:ウインドウ */
 GtkWidget *notebook;                /* ja:ノートブック */
 GtkPositionType n_pos = GTK_POS_TOP;/* ja:ノートブックの位置 */
@@ -61,8 +56,6 @@ GtkItemFactory *ifactory_popup;     /* ja:ポップアップ */
 GtkListStore *list_store;           /* ja:リスト */
 GtkTargetEntry targets_mmaid[] = {  /* ja:提供可能なセレクション */
     {"Melody maid ID3 Tag", 0, TARGET_MMAID}};
-GtkTargetEntry targets_comm[] = {   /* ja:提供可能なセレクション */
-    {"STRING", 0, TARGET_STRING}};
 #ifdef G_OS_WIN32
 UINT uFormat = 0;                   /* ja:クリップボード */
 #endif /* G_OS_WIN32 */
@@ -73,133 +66,6 @@ UINT uFormat = 0;                   /* ja:クリップボード */
 * ja:メイン関数                                                               *
 *                                                                             *
 ******************************************************************************/
-#ifdef G_OS_WIN32
-static DWORD ddeInst = 0;
-static HSZ hszService = NULL;
-static HSZ hszTopic0 = NULL, hszTopic1 = NULL, hszTopic2 = NULL;
-
-
-static HDDEDATA CALLBACK
-DdemlCallback (UINT     uType,
-               UINT     uFmt,
-               HCONV    hConv,
-               HSZ      hszTopic,
-               HSZ      hszServ,
-               HDDEDATA hData,
-               DWORD    dwData1,
-               DWORD    dwData2)
-{
-  switch (uType)
-    {
-      case XTYP_CONNECT:
-        if (DdeCmpStringHandles (hszServ, hszService) != 0)
-          return (HDDEDATA)FALSE;
-        if (DdeCmpStringHandles (hszTopic, hszTopic0) == 0)
-          {
-            hConv = DdeConnect (ddeInst, hszService, hszTopic1, NULL);
-            if (hConv)
-              DdeClientTransaction (NULL, 0, hConv, hszTopic1,
-                                CF_TEXT, XTYP_REQUEST, TIMEOUT_ASYNC, NULL);
-            return (HDDEDATA)TRUE;
-          }
-        else if (DdeCmpStringHandles (hszTopic, hszTopic1) == 0)
-          {
-            return (HDDEDATA)TRUE;
-          }
-        else if (DdeCmpStringHandles (hszTopic, hszTopic2) == 0)
-          {
-            g_free (arg_text);
-            arg_text = NULL;
-            return (HDDEDATA)TRUE;
-          }
-        return (HDDEDATA)FALSE;
-      case XTYP_REQUEST:
-        if (DdeCmpStringHandles (hszTopic, hszTopic1) == 0)
-          return  DdeCreateDataHandle (ddeInst, arg_text,
-                            g_strlen (arg_text) + 1, 0, hszTopic1, CF_TEXT, 0);
-        break;
-      case XTYP_XACT_COMPLETE:
-        if (DdeCmpStringHandles (hszTopic, hszTopic1) == 0)
-          {
-            /* ja:コマンドラインの解析 */
-            gchar *text;
-
-            DdeDisconnect (hConv);
-            text = DdeAccessData (hData, NULL);
-            if (text)
-              {
-                gboolean *arg_files;
-                gchar **argv;
-                gint i, array[2], def[2];
-                ArgumentBool arg_n, arg_x;
-                ArgumentValue arg_h;
-                ArgumentArray arg_s;
-                ArgumentList arg_opts[] = {
-{"history", 'h',  "NUM",          N_("History"),     ARGUMENT_TYPE_VALUE, &arg_h},
-{"new",     'n',  "ON/OFF",       N_("New File"),    ARGUMENT_TYPE_BOOL,  &arg_n},
-{"size",    's',  "WIDTH,HEIGHT", N_("Window Size"), ARGUMENT_TYPE_ARRAY, &arg_s},
-{"second",  'x',  "ON/OFF",       N_("Open Window"), ARGUMENT_TYPE_BOOL,  &arg_x},
-{NULL,      '\0', NULL,           NULL,              0,                   NULL}};
-
-                /* ja:ファイルの履歴 */
-                arg_h.val = history;
-                arg_h.def = 4;
-                /* ja:新規ファイル */
-                arg_n.flag = newfile;
-                arg_n.def = FALSE;
-                /* ja:ウインドウサイズ */
-                array[0] = def_width;
-                array[1] = def_height;
-                def[0] = gdk_screen_width ()  * 2 / 3;
-                def[1] = gdk_screen_height () * 2 / 3;
-                arg_s.leng = 2;
-                arg_s.array = array;
-                arg_s.def = def;
-                /* ja:新規ウインドウ */
-                arg_x.flag = second;
-                arg_x.def = FALSE;
-                /* ja:コマンドラインの解析 */
-                argv = g_strsplit (text, "\n", G_MAXINT);
-                arg_files = arg_analyse (argv, arg_opts);
-                if (history != arg_h.val && 0 <= arg_h.val && arg_h.val <= 10)
-                  {
-                    /* ja:履歴の整理 */
-                    GList *glist;
-                    GtkWidget *menu_shell;
-
-                    history = arg_h.val;
-                    menu_shell = gtk_item_factory_get_widget
-                                                (ifactory_menu, "<main>/File");
-                    glist = gtk_container_children
-                                                (GTK_CONTAINER (menu_shell));
-                    for (i = g_list_length (glist) - 3;
-                            i > history - (history == 0) + MENUFILE - 2; i--)
-                      gtk_container_remove (GTK_CONTAINER
-                                    (menu_shell), g_list_nth_data (glist, i));
-                    g_list_free (glist);
-                  }
-                newfile = arg_n.flag;
-                def_width = array[0];
-                def_height = array[1];
-                second = arg_x.flag;
-                for (i = 1; argv[i]; i++)
-                  if (arg_files[i])
-                    file_open_edit (argv[i]);
-                g_free (arg_files);
-                g_strfreev (argv);
-                DdeUnaccessData (hData);
-              }
-            DdeFreeDataHandle (hData);
-            hConv = DdeConnect (ddeInst, hszService, hszTopic2, NULL);
-            if (hConv)
-              DdeDisconnect (hConv);
-          }
-    }
-  return NULL;
-}
-#endif
-
-
 static gchar *
 menu_translate (const gchar *path, gpointer func_data)
 {
@@ -247,7 +113,7 @@ main (int argc, char *argv[])
 {N_("/Tag/Sep3"),                      NULL,              NULL,            0, "<Separator>"},
 {N_("/Tag/_All"),                      "<control>a",      command_all,     0, "<Item>"},
 {N_("/_Option"),                       NULL,              NULL,            0, "<Branch>"},
-{N_("/Option/_Configuration..."),      NULL,              conf_dialog,     0, "<Item>"},
+{N_("/Option/_Configuration..."),      NULL,              command_conf,    0, "<Item>"},
 {N_("/Option/_Genre..."),              NULL,              genre_dialog,    0, "<Item>"},
 {N_("/Option/Character _Encoding..."), NULL,              command_charset, 0, "<Item>"},
 {N_("/_Window"),                       NULL,              NULL,            0, "<Branch>"},
@@ -500,20 +366,11 @@ MMAID_COPYRIGHT_NOTICE"\n"
   /* ja:クリップボード */
   uFormat = RegisterClipboardFormat (_T("Melody maid ID3 Tag"));
 #endif /* G_OS_WIN32 */
-  /* ja:クリップボード/プロセス間通信 */
+  /* ja:クリップボード */
   atom_targets = gdk_atom_intern ("TARGETS", FALSE);
   atom_id3tag = gdk_atom_intern ("Melody maid ID3 Tag", FALSE);
-  atom_melodymaid0 = gdk_atom_intern
-                        ("Melody maid InterProcess communication 0", FALSE);
-  atom_melodymaid1 = gdk_atom_intern
-                        ("Melody maid InterProcess communication 1", FALSE);
   gtk_selection_add_targets (window, GDK_SELECTION_CLIPBOARD,
             targets_mmaid, sizeof (targets_mmaid) / sizeof (GtkTargetEntry));
-  if (!second)
-    {
-      gtk_selection_add_targets (window, atom_melodymaid0, targets_comm, 1);
-      gtk_selection_add_targets (window, atom_melodymaid1, targets_comm, 1);
-    }
   g_signal_connect (G_OBJECT (window), "selection-clear-event",
                                 G_CALLBACK (signal_selection_clear), NULL);
   g_signal_connect (G_OBJECT(window), "selection-get",
@@ -607,127 +464,16 @@ MMAID_COPYRIGHT_NOTICE"\n"
   /* ja:既に起動しているかチェックする */
   if (!second)
     {
-      gint length = 0;
-#ifdef G_OS_WIN32
-      HCONV hConv;
-#endif /* G_OS_WIN32 */
+      GObject *comm;
 
-      if (argc > 1)
-        for (i = 0; i < argc; i++)
-          {
-            gint leng;
-
-            if (arg_files[i])
-              {
-                gchar *arg;
-
-                arg = fileio_get_full_path (argv[i]);
-                leng = g_strlen (arg) * sizeof (gchar);
-                arg_text = g_realloc (arg_text,
-                                            length + leng + sizeof (gchar));
-                g_memmove (arg_text + length, arg, leng);
-                g_free (arg);
-              }
-            else
-              {
-                leng = g_strlen (argv[i]) * sizeof (gchar);
-                arg_text = g_realloc (arg_text,
-                                            length + leng + sizeof (gchar));
-                g_memmove (arg_text + length, argv[i], leng);
-              }
-            length += leng;
-            arg_text[length++] = '\n';
-          }
-      if (length > 0)
-        arg_text[length - 1] = '\0';
-#ifdef G_OS_WIN32
-      if (DdeInitialize (&ddeInst, DdemlCallback,
-                            APPCLASS_STANDARD | CBF_FAIL_SELFCONNECTIONS, 0)
-                                                            != DMLERR_NO_ERROR)
+      comm = misc_comm_new (window, "Melody maid InterProcess communication");
+      if (!misc_comm_is_first (MISC_COMM (comm)))
         {
-          g_free (arg_files);
+          misc_comm_send_with_files (MISC_COMM (comm), argc, argv, arg_files);
           gtk_exit (0);
         }
-      hszService = DdeCreateStringHandle (ddeInst,
-                                _T("Melody maid InterProcess communication"),
-# ifdef UNICODE
-                                                                CP_WINANSI);
-# else /* not UNICODE */
-                                                                CP_WINUNICODE);
-# endif
-      hszTopic0 = DdeCreateStringHandle (ddeInst,
-                                _T("Melody maid InterProcess communication 0"),
-# ifdef UNICODE
-                                                                CP_WINANSI);
-# else /* not UNICODE */
-                                                                CP_WINUNICODE);
-# endif
-      hszTopic1 = DdeCreateStringHandle (ddeInst,
-                                _T("Melody maid InterProcess communication 1"),
-# ifdef UNICODE
-                                                                CP_WINANSI);
-# else /* not UNICODE */
-                                                                CP_WINUNICODE);
-# endif
-      hszTopic2 = DdeCreateStringHandle (ddeInst,
-                                _T("Melody maid InterProcess communication 2"),
-# ifdef UNICODE
-                                                                CP_WINANSI);
-# else /* not UNICODE */
-                                                                CP_WINUNICODE);
-# endif
-      if (!hszService || !hszTopic0 || !hszTopic1 || !hszTopic2)
-        {
-          if (hszService)
-            DdeFreeStringHandle (ddeInst, hszService);
-          if (hszTopic0)
-            DdeFreeStringHandle (ddeInst, hszTopic0);
-          if (hszTopic1)
-            DdeFreeStringHandle (ddeInst, hszTopic1);
-          if (hszTopic2)
-            DdeFreeStringHandle (ddeInst, hszTopic2);
-          DdeUninitialize (ddeInst);
-          g_free (arg_files);
-          gtk_exit (0);
-        }
-      DdeNameService (ddeInst, hszService, NULL, DNS_REGISTER);
-      hConv = DdeConnect (ddeInst, hszService, hszTopic0, NULL);
-      if (hConv)
-        {
-          /* ja:既に起動しているとき */
-          DdeDisconnect (hConv);
-          while (arg_text)
-            while (gtk_events_pending ())
-              gtk_main_iteration ();
-          DdeNameService (ddeInst, hszService, NULL, DNS_UNREGISTER);
-          DdeFreeStringHandle (ddeInst, hszService);
-          DdeFreeStringHandle (ddeInst, hszTopic0);
-          DdeFreeStringHandle (ddeInst, hszTopic1);
-          DdeFreeStringHandle (ddeInst, hszTopic2);
-          DdeUninitialize (ddeInst);
-          g_free (arg_files);
-          gtk_exit (0);
-        }
-#else /* not G_OS_WIN32 */
-      if (length > 0)
-        gtk_selection_owner_set (window, atom_melodymaid1, GDK_CURRENT_TIME);
-      gtk_selection_convert (window, atom_melodymaid0,
-                                GDK_SELECTION_TYPE_STRING, GDK_CURRENT_TIME);
-      while (instance < 0)
-        while (gtk_events_pending ())
-          gtk_main_iteration ();
-      if (instance > 0)
-        {
-          /* ja:既に起動しているとき */
-          while (arg_text)
-            while (gtk_events_pending ())
-              gtk_main_iteration ();
-          g_free (arg_files);
-          gtk_exit (0);
-        }
-      gtk_selection_owner_set (window, atom_melodymaid0, GDK_CURRENT_TIME);
-#endif /* not G_OS_WIN32 */
-      g_free (arg_text);
+      g_signal_connect (G_OBJECT (comm), "recv",
+                                    G_CALLBACK (signal_selection_recv), NULL);
     }
 
   /* ja:表示 */
@@ -874,17 +620,6 @@ MMAID_COPYRIGHT_NOTICE"\n"
   g_free (open_path);
   g_free (save_path);
   g_free (clipboard_id3tag);
-#ifdef G_OS_WIN32
-    if (ddeInst != 0)
-      {
-        DdeNameService (ddeInst, hszService, NULL, DNS_UNREGISTER);
-        DdeFreeStringHandle (ddeInst, hszService);
-        DdeFreeStringHandle (ddeInst, hszTopic0);
-        DdeFreeStringHandle (ddeInst, hszTopic1);
-        DdeFreeStringHandle (ddeInst, hszTopic2);
-        DdeUninitialize (ddeInst);
-      }
-#endif /* G_OS_WIN32 */
   for (i = 0; i < history; i++)
     g_free (history_files[i]);
   return 0;
