@@ -167,30 +167,11 @@ signal_selection_get (GtkWidget        *widget,
                       guint             time,
                       gpointer          user_data)
 {
-  gchar *text;
-
-  if (data->selection == GDK_SELECTION_CLIPBOARD)
-    {
-      /* ja:クリップボード */
-      if (clipboard_id3tag && info == TARGET_MMAID)
-        gtk_selection_data_set (data, atom_id3tag, 8,
+  /* ja:クリップボード */
+  if (data->selection == GDK_SELECTION_CLIPBOARD
+                                && clipboard_id3tag && info == TARGET_MMAID)
+    gtk_selection_data_set (data, atom_id3tag, 8,
                     (guchar *)clipboard_id3tag, g_strlen (clipboard_id3tag));
-    }
-  else if (data->selection == atom_melodymaid0)
-    {
-      /* ja:プロセス間通信 */
-      text = "Melody maid Selection";
-      gtk_selection_data_set_text (data, text, g_strlen (text));
-      gtk_selection_convert (window, atom_melodymaid1,
-                                GDK_SELECTION_TYPE_STRING, GDK_CURRENT_TIME);
-    }
-  else if (data->selection == atom_melodymaid1 && arg_text)
-    {
-      /* ja:プロセス間通信 */
-      gtk_selection_data_set_text (data, arg_text, g_strlen (arg_text));
-      g_free (arg_text);
-      arg_text = NULL;
-    }
 }
 
 
@@ -200,166 +181,160 @@ signal_selection_received (GtkWidget        *widget,
                            guint             time,
                            gpointer          user_data)
 {
-  MmaidWindow *mmaid;
-
-  if (data->selection == GDK_SELECTION_CLIPBOARD)
+  /* ja:クリップボード */
+  if (data->selection == GDK_SELECTION_CLIPBOARD && data->length >= 0)
     {
-      /* ja:クリップボード */
-      if (data->length >= 0)
+      if (data->type == GDK_SELECTION_TYPE_ATOM)
         {
-          if (data->type == GDK_SELECTION_TYPE_ATOM)
-            {
-              gint i, count;
-              GdkAtom *atoms;
+          gint i, count;
+          GdkAtom *atoms;
 
-              atoms = (GdkAtom *)data->data;
-              count = data->length / sizeof (GdkAtom);
-              for (i = 0; i < count; i++)
-                if (atoms[i] == atom_id3tag)
-                  break;
-              if (i < count)
-                gtk_selection_convert (widget, data->selection, atoms[i],
+          atoms = (GdkAtom *)data->data;
+          count = data->length / sizeof (GdkAtom);
+          for (i = 0; i < count; i++)
+            if (atoms[i] == atom_id3tag)
+              break;
+          if (i < count)
+            gtk_selection_convert (widget, data->selection, atoms[i],
                                                             GDK_CURRENT_TIME);
-            }
-          else if (data->type == atom_id3tag)
-            {
-              gchar **tag;
-              gint i, n, c;
+        }
+      else if (data->type == atom_id3tag)
+        {
+          gchar **tag;
+          gint i, n, c;
+          MmaidWindow *mmaid;
 
-              /* ja:貼り付け */
-              mmaid = g_object_get_data (G_OBJECT
+          /* ja:貼り付け */
+          mmaid = g_object_get_data (G_OBJECT
                     (gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook),
                     gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook)))),
                                                                 "user_data");
-              mm_list_get_cursor (MM_LIST (mmaid->list), &n, &c);
-              mm_list_unselect_all (MM_LIST (mmaid->list));
-              tag = g_strsplit (data->data, "\n", G_MAXINT);
-              for (i = 0; tag[i]; i++)
-                {
-                  gchar **a;
-                  gint s;
-                  ID3Tag *id3tag;
+          mm_list_get_cursor (MM_LIST (mmaid->list), &n, &c);
+          mm_list_unselect_all (MM_LIST (mmaid->list));
+          tag = g_strsplit (data->data, "\n", G_MAXINT);
+          for (i = 0; tag[i]; i++)
+            {
+              gchar **a;
+              gint s;
+              ID3Tag *id3tag;
 
-                  id3tag = g_malloc (sizeof (ID3Tag));
-                  a = g_strsplit (tag[i], "\t", G_MAXINT);
-                  id3tag->file    = a[0] != '\0' ? g_strdup (a[0]) : NULL;
-                  id3tag->title   = a[1] != '\0' ? g_strdup (a[1]) : NULL;
-                  id3tag->artist  = a[2] != '\0' ? g_strdup (a[2]) : NULL;
-                  id3tag->album   = a[3] != '\0' ? g_strdup (a[3]) : NULL;
-                  id3tag->year    = a[4] != '\0' ? g_strdup (a[4]) : NULL;
-                  id3tag->comment = a[5] != '\0' ? g_strdup (a[5]) : NULL;
-                  misc_str_to_val (&id3tag->track, a[6], 10, TRUE);
-                  id3tag->genre   = a[7] != '\0' ? g_strdup (a[7]) : NULL;
-                  id3tag->charset = a[8] != '\0' ? g_strdup (a[8]) : NULL;
-                  g_strfreev (a);
-                  s = mm_list_search (MM_LIST (mmaid->list),
+              id3tag = g_malloc (sizeof (ID3Tag));
+              a = g_strsplit (tag[i], "\t", G_MAXINT);
+              id3tag->file    = a[0] != '\0' ? g_strdup (a[0]) : NULL;
+              id3tag->title   = a[1] != '\0' ? g_strdup (a[1]) : NULL;
+              id3tag->artist  = a[2] != '\0' ? g_strdup (a[2]) : NULL;
+              id3tag->album   = a[3] != '\0' ? g_strdup (a[3]) : NULL;
+              id3tag->year    = a[4] != '\0' ? g_strdup (a[4]) : NULL;
+              id3tag->comment = a[5] != '\0' ? g_strdup (a[5]) : NULL;
+              misc_str_to_val (&id3tag->track, a[6], 10, TRUE);
+              id3tag->genre   = a[7] != '\0' ? g_strdup (a[7]) : NULL;
+              id3tag->charset = a[8] != '\0' ? g_strdup (a[8]) : NULL;
+              g_strfreev (a);
+              s = mm_list_search (MM_LIST (mmaid->list),
                                             MM_LIST_FILE, id3tag->file, -1);
-                  if (s >= 0)
-                    mm_list_change (MM_LIST (mmaid->list), s,
+              if (s >= 0)
+                mm_list_change (MM_LIST (mmaid->list), s,
                                                 MM_LIST_ID3TAG, id3tag, -1);
-                  else if (n >= 0)
-                    n = mm_list_insert (MM_LIST (mmaid->list), n, id3tag);
-                  else
-                    n = mm_list_append (MM_LIST (mmaid->list), id3tag);
-                  mm_list_select (MM_LIST (mmaid->list), n);
-                }
-              g_strfreev (tag);
-              mm_list_set_cursor (MM_LIST (mmaid->list), n, c);
-              mmaid_change_edit (mmaid, TRUE);
+              else if (n >= 0)
+                n = mm_list_insert (MM_LIST (mmaid->list), n, id3tag);
+              else
+                n = mm_list_append (MM_LIST (mmaid->list), id3tag);
+              mm_list_select (MM_LIST (mmaid->list), n);
             }
+          g_strfreev (tag);
+          mm_list_set_cursor (MM_LIST (mmaid->list), n, c);
+          mmaid_change_edit (mmaid, TRUE);
         }
     }
-  else if (data->selection == atom_melodymaid0)
-    {
-      /* ja:プロセス間通信 */
-      instance = MAX (data->length, 0);
-    }
-  else if (data->selection == atom_melodymaid1 && data->length > 0)
-    {
-      gboolean *arg_files;
-      gchar **argv;
-      gint i, array[2], def[2];
-      ArgumentBool arg_n, arg_x;
-      ArgumentValue arg_h;
-      ArgumentArray arg_s;
-      ArgumentList arg_opts[] = {
+
+}
+
+
+void
+signal_selection_recv (GObject   *object,
+                       gchar    **argv,
+                       gpointer   user_data)
+{
+  gboolean *arg_files;
+  gint i, array[2], def[2];
+  MmaidWindow *mmaid;
+  ArgumentBool arg_n, arg_x;
+  ArgumentValue arg_h;
+  ArgumentArray arg_s;
+  ArgumentList arg_opts[] = {
 {"history", 'h',  "NUM",          N_("History"),     ARGUMENT_TYPE_VALUE, &arg_h},
 {"new",     'n',  "ON/OFF",       N_("New File"),    ARGUMENT_TYPE_BOOL,  &arg_n},
 {"size",    's',  "WIDTH,HEIGHT", N_("Window Size"), ARGUMENT_TYPE_ARRAY, &arg_s},
 {"second",  'x',  "ON/OFF",       N_("Open Window"), ARGUMENT_TYPE_BOOL,  &arg_x},
 {NULL,      '\0', NULL,           NULL,              0,                   NULL}};
 
-      i = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
-      mmaid = i >= 0 ? g_object_get_data (G_OBJECT (gtk_notebook_get_nth_page
+  i = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
+  mmaid = i >= 0 ? g_object_get_data (G_OBJECT (gtk_notebook_get_nth_page
                             (GTK_NOTEBOOK (notebook), i)), "user_data") : NULL;
-      /* ja:プロセス間通信 */
-      /* ja:ファイルの履歴 */
-      arg_h.val = history;
-      arg_h.def = 4;
-      /* ja:新規ファイル */
-      arg_n.flag = newfile;
-      arg_n.def = FALSE;
-      /* ja:ウインドウサイズ */
-      array[0] = def_width;
-      array[1] = def_height;
-      def[0] = gdk_screen_width ()  * 2 / 3;
-      def[1] = gdk_screen_height () * 2 / 3;
-      arg_s.leng = 2;
-      arg_s.array = array;
-      arg_s.def = def;
-      /* ja:新規ウインドウ */
-      arg_x.flag = second;
-      arg_x.def = FALSE;
-      /* ja:コマンドラインの解析 */
-      argv = g_strsplit (data->data, "\n", G_MAXINT);
-      arg_files = arg_analyse (argv, arg_opts);
-      if (history != arg_h.val && 0 <= arg_h.val && arg_h.val <= 10)
-        {
-          /* ja:履歴の整理 */
-          GList *glist;
-          GtkWidget *menu_shell;
+  /* ja:プロセス間通信 */
+  /* ja:ファイルの履歴 */
+  arg_h.val = history;
+  arg_h.def = 4;
+  /* ja:新規ファイル */
+  arg_n.flag = newfile;
+  arg_n.def = FALSE;
+  /* ja:ウインドウサイズ */
+  array[0] = def_width;
+  array[1] = def_height;
+  def[0] = gdk_screen_width ()  * 2 / 3;
+  def[1] = gdk_screen_height () * 2 / 3;
+  arg_s.leng = 2;
+  arg_s.array = array;
+  arg_s.def = def;
+  /* ja:新規ウインドウ */
+  arg_x.flag = second;
+  arg_x.def = FALSE;
+  /* ja:コマンドラインの解析 */
+  arg_files = arg_analyse (argv, arg_opts);
+  if (history != arg_h.val && 0 <= arg_h.val && arg_h.val <= 10)
+    {
+      /* ja:履歴の整理 */
+      GList *glist;
+      GtkWidget *menu_shell;
 
-          history = arg_h.val;
-          menu_shell = gtk_item_factory_get_widget
-                                                (ifactory_menu, "<main>/File");
-          glist = gtk_container_children (GTK_CONTAINER (menu_shell));
-          for (i = g_list_length (glist) - 3;
+      history = arg_h.val;
+      menu_shell = gtk_item_factory_get_widget (ifactory_menu, "<main>/File");
+      glist = gtk_container_children (GTK_CONTAINER (menu_shell));
+      for (i = g_list_length (glist) - 3;
                             i > history - (history == 0) + MENUFILE - 2; i--)
-            gtk_container_remove (GTK_CONTAINER
+        gtk_container_remove (GTK_CONTAINER
                                     (menu_shell), g_list_nth_data (glist, i));
-          g_list_free (glist);
-        }
-      newfile = arg_n.flag;
-      def_width = array[0];
-      def_height = array[1];
-      second = arg_x.flag;
-      for (i = 1; argv[i]; i++)
-        if (arg_files[i])
-          switch (file_is_type (argv[i]))
+      g_list_free (glist);
+    }
+  newfile = arg_n.flag;
+  def_width = array[0];
+  def_height = array[1];
+  second = arg_x.flag;
+  for (i = 1; argv[i]; i++)
+    if (arg_files[i])
+      switch (file_is_type (argv[i]))
+        {
+          case FILE_KIND_ERROR:
+          case FILE_KIND_DB:
+            mmaid = file_open_edit (argv[i]);
+            break;
+          case FILE_KIND_UNKNOWN:
+          case FILE_KIND_TAG:
             {
-              case FILE_KIND_ERROR:
-              case FILE_KIND_DB:
-                mmaid = file_open_edit (argv[i]);
-                break;
-              case FILE_KIND_UNKNOWN:
-              case FILE_KIND_TAG:
-                {
-                  ID3Tag *id3tag;
+              ID3Tag *id3tag;
 
-                  id3tag = file_open_id3tag (argv[i], charset_list);
-                  if (id3tag)
-                    {
-                      if (!mmaid || mm_list_search (MM_LIST (mmaid->list),
+              id3tag = file_open_id3tag (argv[i], charset_list);
+              if (id3tag)
+                {
+                  if (!mmaid || mm_list_search (MM_LIST (mmaid->list),
                                         MM_LIST_FILE, id3tag->file, -1) >= 0)
-                        mmaid = file_open_edit (NULL);
-                      mm_list_append (MM_LIST (mmaid->list), id3tag);
-                      mmaid_change_edit (mmaid, TRUE);
-                    }
+                    mmaid = file_open_edit (NULL);
+                  mm_list_append (MM_LIST (mmaid->list), id3tag);
+                  mmaid_change_edit (mmaid, TRUE);
                 }
             }
-      g_free (arg_files);
-      g_strfreev (argv);
-    }
+        }
+  g_free (arg_files);
 }
 
 
